Transmogrify 0.1 documentation — Transmogrify v0.2beta0 documentation

Transmogrify v0.2beta0 documentation

# Transmogrify 0.1 documentation

- Table of Contents
- index
  next

# Transmogrify 0.1 documentation

Contents:

- Getting Started
  - The URL Generator
- Installation
  - Dependencies
- Django Template Tag
  - transmogrify
  - thumbnail
  - resize
  - letterbox
  - forcefit
  - crop
  - filter
  - border
- Web Server Integration
  - Lighttpd Integration
  - Django Development Server Integration
- Reference
  - Settings

# Indices and tables

- Index
- Module Index
- Search Page